Control Panel » KENZY.Ai [__APP_VERSION__]

X My Title
CONTENT HERE
KENZY.Ai[__APP_VERSION__]

## Devices

Container | Device | Status | Action
--- | --- | --- | ---
No devices found.

Show Log Word Wrap

### Request

### Output

## Commands

Show Log Word Wrap

### Request

### Output

## About

Kenzy is a foundation of Python code that enables hardware interactions leveraging Machine Learning to create Artificial Intelligence. Wow, that's a mouthful. Let's try again, Kenzy is a set of Python classes and functions that you can use to build your own personal assistant similar to Apple's Siri, Google's Assistant, or Amazon's Alexa. There are libraries for speech recognition, speech synthesis, face and object detection, and even face recognition. So basically Kenzy can see you, hear you, and respond to you.

Kenzy is 100% customizable. Its modular design allows you to create your own skills or integrate new hardware to fit your specific needs. The code is open source and shared with a business-friendly license.

### What Should You Expect?

Kenzy's main goal is to share knowledge and grow organically based on feedback and support from people like you. On the project web site, the github project, and within each of Kenzy's code modules you will find lots of documentation, examples, sample code, and other artifacts to help you grow in your own experience with Ai/ML and coding.

### Who Built Me

Kenzy was originally designed by @lnxusr1 during the Covid-19 lockdown in 2020.